<?php
/**
 * HomePage Posts
 *
 * @package Blocks
 */

$features = blocks_get_settings( 'mts_featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['mts_thumb_layout'] ) ? $feature['mts_thumb_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus[ 'homepage-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'blocks' ) ), $title ),
	);

	$sections[ 'homepage-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Blocks
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'blocks' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'blocks' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'blocks' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '20px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'blocks' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'blocks' ),
			'sub_desc'   => esc_html__( 'Select border', 'blocks' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'blocks' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '500',
				'font-size'     => '27px',
				'color'         => '#091e42',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		// View More
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'blocks' ),
			'std'      => '0',
		) : null,
		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'blocks' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'home_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'blocks' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'blocks' ),
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '16px',
				'color'          => blocks_get_settings( 'mts_color_scheme' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'home_category_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'blocks' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'blocks' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'blocks' ),
			'std'      => array(
				'top'    => '7px',
				'right'  => '0',
				'bottom' => '20px',
				'left'   => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'blocks' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'color'          => '#97a0af',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore.', 'blocks' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'blocks' ),
			'std'        => '#f2f3f6',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Font', 'blocks' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '20px',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '500',
				'font-size'     => '27px',
				'line-height'   => '45px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '28px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1.
		 *
		 * @package Blocks
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'blocks' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'blocks' ),
			'std'      => '1',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'blocks' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '20px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'blocks' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'blocks' ),
			'sub_desc'   => esc_html__( 'Select border', 'blocks' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'blocks' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '700',
				'font-size'     => '26px',
				'line-height'   => '42px',
				'color'         => '#091e42',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		// View More
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'blocks' ),
			'std'      => '1',
		) : null,
		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'blocks' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'home_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'blocks' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'blocks' ),
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '16px',
				'color'          => blocks_get_settings( 'mts_color_scheme' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'home_category_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'blocks' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'blocks' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'blocks' ),
			'std'      => array(
				'top'    => '8px',
				'right'  => '0',
				'bottom' => '15px',
				'left'   => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'blocks' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'color'          => '#97a0af',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore.', 'blocks' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'blocks' ),
			'std'        => '#f2f3f6',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Font', 'blocks' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Post Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '500',
				'font-size'     => '27px',
				'line-height'   => '42px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '23px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 2.
		 *
		 * @package Blocks
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'blocks' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'blocks' ),
			'std'      => '1',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'blocks' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '20px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'blocks' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'blocks' ),
			'sub_desc'   => esc_html__( 'Select border', 'blocks' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'blocks' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '700',
				'font-size'     => '26px',
				'line-height'   => '42px',
				'color'         => '#091e42',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		// View More
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'View More Button', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide view more button.', 'blocks' ),
			'std'      => '1',
		) : null,
		// Meta info.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'blocks' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'home_category_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Category', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide category.', 'blocks' ),
			'std'      => '0',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_category_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Category Typography', 'blocks' ),
			'std'        => array(
				'preview-text'   => 'Category Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '13px',
				'color'          => blocks_get_settings( 'mts_color_scheme' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .thecategory a',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'home_category_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'blocks' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'blocks' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
					'date'   => array(
						'label'     => esc_html__( 'Date', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'blocks' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'blocks' ),
							),
						),
					),
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'blocks' ),
			'std'      => array(
				'top'    => '10px',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'blocks' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '12px',
				'color'          => '#97a0af',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Post Container.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore.', 'blocks' ),
			'std'      => '0',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'blocks' ),
			'std'        => '#f2f3f6',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Font', 'blocks' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Post Font',
				'preview-color' => 'light',
				'font-family'   => 'Roboto',
				'font-weight'   => '500',
				'font-size'     => '20px',
				'line-height'   => '30px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		/**
		 * Layout Partners.
		 *
		 * @package Blocks
		 */

		( 'layout-partners' === $posts_layout ) ? array(
			'id'        => 'partners_section_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Partners Items', 'blocks' ),
			'groupname' => esc_html__( 'Partner Item', 'blocks' ),
			'subfields' => array(
				array(
					'id'    => 'partner_title',
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'blocks' ),
				),
				array(
					'id'       => 'partner_image',
					'type'     => 'upload',
					'title'    => esc_html__( 'Image', 'blocks' ),
					'sub_desc' => esc_html__( 'Upload or select an image for partner. Recommended Size(190X70px)', 'blocks' ),
				),
				array(
					'id'       => 'partner_url',
					'type'     => 'text',
					'title'    => esc_html__( 'Link', 'blocks' ),
					'sub_desc' => esc_html__( 'Insert a link URL of partner', 'blocks' ),
					'std'      => '#',
				),
			),
		) : null,

		// Section Title.
		( 'layout-partners' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'blocks' ),
		) : null,

		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'blocks' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'blocks' ),
			'std'      => '1',
		) : null,

		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'partner_section_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Section Title', 'blocks' ),
			'sub_desc'   => esc_html__( 'Partners section title.', 'blocks' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'partners_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Partners Title Font', 'blocks' ),
			'std'        => array(
				'preview-text'   => 'Partners Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Roboto',
				'font-weight'    => '400',
				'font-size'      => '16px',
				'line-height'    => '19px',
				'color'          => '#091e42',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.article.layout-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'post_title_shadow' . $unique_id,
			'type'       => 'switch',
			'title'      => esc_html__( 'Box Shadow', 'blocks' ),
			'sub_desc'   => esc_html__( 'Use this button to show or hide box shadow in post container.', 'blocks' ),
			'std'        => '1',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'blocks' ),
			'left'       => false,
			'right'      => false,
			'std'        => array(
				'top'    => '0',
				'bottom' => '20px',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'blocks' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'blocks' ),
			'std'        => array(
				'left'   => '40px',
				'top'    => '40px',
				'right'  => '40px',
				'bottom' => '40px',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'blocks' ),
			'sub_desc'   => esc_html__( 'Select border', 'blocks' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		// Post Container.
		( 'layout-partners' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		/**
		 * Layout Category.
		 *
		 * @package Blocks
		 */

		( 'layout-category' === $posts_layout ) ? array(
			'id'        => 'cat_section_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Category items', 'blocks' ),
			'sub_desc'  => esc_html__( 'Add category Item from here', 'blocks' ),
			'groupname' => esc_html__( 'Category item', 'blocks' ),
			'subfields' => array(
				array(
					'id'    => 'cat_section_title',
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'blocks' ),
				),
				array(
					'id'       => 'cat_section_category',
					'type'     => 'select',
					'title'    => esc_html__( 'Category', 'blocks' ),
					'sub_desc' => esc_html__( 'Select a category for this section', 'blocks' ),
					'data'     => 'category',
				),
				array(
					'id'       => 'cat_section_image',
					'type'     => 'upload',
					'title'    => esc_html__( 'Image', 'blocks' ),
					'sub_desc' => esc_html__( 'Upload or select an image for category. Recommended Size(365X287px)', 'blocks' ),
				),
				array(
					'id'    => 'cat_section_background',
					'type'  => 'color',
					'title' => esc_html__( 'Select overlay color for your category', 'blocks' ),
					'args'  => array( 'opacity' => true ),
					'std'   => 'rgba(0, 0, 0, 0.3)',
				),
				array(
					'id'    => 'cat_section_hover_background',
					'type'  => 'color',
					'title' => esc_html__( 'Select overlay hover color for your category', 'blocks' ),
					'args'  => array( 'opacity' => true ),
					'std'   => 'rgba(0, 0, 0, 0.6)',
				),
			),
		) : null,

		// Post Container.
		( 'layout-category' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		/**
		 * Layout Subscribe.
		 *
		 * @package Blocks
		 */

		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'subscribe_size_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Section Size', 'blocks' ),
			'sub_desc' => esc_html__( 'Select the size of subscribe widget.', 'blocks' ),
			'options'  => array(
				'full'      => esc_html__( 'Full', 'blocks' ),
				'container' => esc_html__( 'Container', 'blocks' ),
			),
			'std'      => 'full',
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'subscribe_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Alignment', 'blocks' ),
			'sub_desc' => esc_html__( 'Alignment of subscribe widget content', 'blocks' ),
			'options'  => array(
				'left'   => esc_html__( 'Left', 'blocks' ),
				'center' => esc_html__( 'Center', 'blocks' ),
				'right'  => esc_html__( 'Right', 'blocks' ),
			),
			'std'      => 'center',
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Typography', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'dark',
				'font-family'   => 'Roboto',
				'font-weight'   => '500',
				'font-size'     => '28px',
				'font-size'     => '32px',
				'color'         => '#091e42',
				'css-selectors' => '.layout-' . $unique_id . ' .widget #wp-subscribe .title, .layout-' . $unique_id . ' .layout-subscribe .left-content h4',
			),
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'subscribe_input_background_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Input Fields Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'blocks' ),
			'std'      => '#ffffff',
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'subscribe_input_size_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Input Field Size', 'blocks' ),
			'sub_desc' => esc_html__( 'Select the size of input fields.', 'blocks' ),
			'options'  => array(
				'large' => esc_html__( 'Large', 'blocks' ),
				'small' => esc_html__( 'Small', 'blocks' ),
			),
			'std'      => 'large',
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_input_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Input Fields Typography', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Input Fields Font',
				'preview-color' => 'dark',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-subscribe #wp-subscribe input.email-field, .layout-' . $unique_id . ' .layout-subscribe #wp-subscribe input.name-field',
			),
		) : null,

		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Typography', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Text Font',
				'preview-color' => 'dark',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '28px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-subscribe #wp-subscribe p.text, .layout-' . $unique_id . ' .subscribe-icons-container p, .layout-' . $unique_id . ' .layout-subscribe .left-content p',
			),
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_small_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Small Text Typography', 'blocks' ),
			'std'   => array(
				'preview-text'  => 'Text Font',
				'preview-color' => 'dark',
				'font-family'   => 'Roboto',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-subscribe #sidebar .wp-subscribe-wrap p.footer-text, .layout-' . $unique_id . ' .layout-subscribe #sidebar .widget .wp-subscribe .wps-consent-wrapper',
			),
		) : null,

		// Left Content.
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_left_content_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Subscribe Left Content', 'blocks' ),
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'subscribe_left_content_logo_' . $unique_id,
			'type'     => 'upload',
			'title'    => esc_html__( 'Left Content Logo', 'blocks' ),
			'sub_desc' => esc_html__( 'Select an image file for left content logo.', 'blocks' ),
			'return'   => 'url',
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_left_content_title_' . $unique_id,
			'type'  => 'text',
			'title' => esc_html__( 'Left Content Title', 'blocks' ),
			'std'   => 'Know where to go!',
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_left_content_text_' . $unique_id,
			'type'  => 'textarea',
			'title' => esc_html__( 'Left Content Text', 'blocks' ),
			'std'   => 'Sign up for our daily tips to make your best vacation.',
		) : null,

		// Social Icons.
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'subscribe_icon_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Subscribe Social Icons', 'blocks' ),
		) : null,

		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'subscribe_social_icons_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Subscribe Social Icons', 'blocks' ),
			'sub_desc' => esc_html__( 'Enable or disable subscribe social icons with this option.', 'blocks' ),
			'std'      => '1',
		) : null,

		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'         => 'subscribe_icon_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Title', 'blocks' ),
			'sub_desc'   => esc_html__( 'Subscribe icon title.', 'blocks' ),
			'std'        => 'Follow Us',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'subscribe_social_icons_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'         => 'subscribe_social_' . $unique_id,
			'title'      => esc_html__( 'Footer Social Icons', 'blocks' ),
			'sub_desc'   => esc_html__( 'Add Social Media icons in footer nav section.', 'blocks' ),
			'type'       => 'group',
			'groupname'  => esc_html__( 'Social Icons', 'blocks' ), // Group name.
			'subfields'  => array(
				array(
					'id'    => 'subscribe_social_title',
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'blocks' ),
				),
				array(
					'id'    => 'subscribe_social_icon',
					'type'  => 'icon_select',
					'title' => esc_html__( 'Icon', 'blocks' ),
				),
				array(
					'id'    => 'subscribe_social_link',
					'type'  => 'text',
					'title' => esc_html__( 'URL', 'blocks' ),
				),
				array(
					'id'    => 'subscribe_social_color',
					'type'  => 'color',
					'title' => esc_html__( 'Icon color', 'blocks' ),
				),
				array(
					'id'    => 'subscribe_social_hover_color',
					'type'  => 'color',
					'title' => esc_html__( 'Icon hover color', 'blocks' ),
				),
				array(
					'id'    => 'subscribe_social_margin',
					'type'  => 'margin',
					'title' => esc_html__( 'Margin', 'blocks' ),
				),
				array(
					'id'    => 'subscribe_social_padding',
					'type'  => 'margin',
					'title' => esc_html__( 'Padding', 'blocks' ),
				),
			),
			'std'        => array(
				'facebook'  => array(
					'group_title'                  => 'Facebook',
					'group_sort'                   => '1',
					'subscribe_social_title'       => 'Facebook',
					'subscribe_social_icon'        => 'facebook-square',
					'subscribe_social_link'        => '#',
					'subscribe_social_color'       => '#97a0af',
					'subscribe_social_hover_color' => blocks_get_settings( 'mts_color_scheme' ),
					'subscribe_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'subscribe_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'youtube'   => array(
					'group_title'                  => 'Youtube',
					'group_sort'                   => '1',
					'subscribe_social_title'       => 'Youtube',
					'subscribe_social_icon'        => 'youtube',
					'subscribe_social_link'        => '#',
					'subscribe_social_color'       => '#97a0af',
					'subscribe_social_hover_color' => blocks_get_settings( 'mts_color_scheme' ),
					'subscribe_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'subscribe_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'twitter'   => array(
					'group_title'                  => 'Twitter',
					'group_sort'                   => '3',
					'subscribe_social_title'       => 'Twitter',
					'subscribe_social_icon'        => 'twitter',
					'subscribe_social_link'        => '#',
					'subscribe_social_color'       => '#97a0af',
					'subscribe_social_hover_color' => blocks_get_settings( 'mts_color_scheme' ),
					'subscribe_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'subscribe_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'pinterest' => array(
					'group_title'                  => 'Pinterest',
					'group_sort'                   => '4',
					'subscribe_social_title'       => 'Pinterest',
					'subscribe_social_icon'        => 'pinterest',
					'subscribe_social_link'        => '#',
					'subscribe_social_color'       => '#97a0af',
					'subscribe_social_hover_color' => blocks_get_settings( 'mts_color_scheme' ),
					'subscribe_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'subscribe_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'instagram' => array(
					'group_title'                  => 'Instagram',
					'group_sort'                   => '5',
					'subscribe_social_title'       => 'Instagram',
					'subscribe_social_icon'        => 'instagram',
					'subscribe_social_link'        => '#',
					'subscribe_social_color'       => '#97a0af',
					'subscribe_social_hover_color' => blocks_get_settings( 'mts_color_scheme' ),
					'subscribe_social_margin'      => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
					'subscribe_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'subscribe_social_icons_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		// Post Container.
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '#f7f8fa',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#f7f8fa',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-subscribe' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '50px',
				'right'  => '0',
				'bottom' => '50px',
			),
		) : null,

		/**
		 * Layout Ad.
		 *
		 * @package Blocks
		 */

		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'adcode_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'Ad Code', 'blocks' ),
			'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads.', 'blocks' ),
		) : null,

		// Post Container.
		( 'layout-ad' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'blocks' ),
		) : null,

		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'blocks' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'blocks' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'blocks' ),
			'sub_desc' => esc_html__( 'Select border', 'blocks' ),
		) : null,
		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'blocks' ),
			'sub_desc' => esc_html__( 'Post margin.', 'blocks' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'blocks' ),
			'sub_desc' => esc_html__( 'Post padding.', 'blocks' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
